﻿RightBG = CreateFrame("Frame","Move_RightBG",UIParent)
RightBG:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", -15, 39)
CreateAnchor(RightBG, "Move right bg frame", 20, 20)

local module = {}
module.name = "cfgPanels"
module.Init = function()
	if not tDB.modules[module.name] then return end
	local settings = tDB

if tDB["cfgPanels"]["rBackground"] then
	RightBG:SetWidth(tDB["cfgPanels"]["width"])
	RightBG:SetHeight(tDB["cfgPanels"]["height"])
end

------------------------------------------------------------------------------------------
-- LitePanels
------------------------------------------------------------------------------------------
local lp, hidden, deps = CreateFrame('Frame','lp_C'), {}, {} lp:Hide()

lpanels = {
	profile = {}, temp = {},
	cinfo = {
		n = strlower(UnitName'player'),
		r = strlower(gsub(GetRealmName()," ","")),
		c = strlower(select(2,UnitClass'player'))
	},
	defaults = {
		parent = "UIParent", strata = "BACKGROUND",
		anchor_to = "BOTTOMLEFT", anchor_from = "BOTTOMLEFT",
		x_off = 0, y_off = 0, height = 0, width = 0,
		bg_color = "0 0 0", bg_alpha = 1, gradient_color = "1 1 1",
		border = "Interface/Tooltips/UI-Tooltip-Border",
		border_size = 16, border_color = "1 1 1", border_alpha = 1,
		text = {
			string = "", font = "Fonts/FRIZQT__.TTF", size = 12,
			justify_h = "CENTER", justify_v = "MIDDLE",
			anchor_to = "CENTER", anchor_from = "CENTER",
			x_off = 0, y_off = 0, color = "1 1 1", alpha = 1,
			shadow = { color = "0 0 0", alpha = 1, y = -1, x = 1 },
		}
	},
	media = [[Interface\AddOns\LitePanels\media\]],
	sides = {'left','top','right','bottom'},
	events = {'OnEvent','OnUpdate','OnResize','OnClick','OnDoubleClick',
		'OnMouseUp','OnMouseDown','OnEnter','OnLeave','OnHide','OnShow'},
	defaultv = {'anchor_to','x_off','y_off','width','height','strata'},
}

local gsub = string.gsub
local strmatch = string.match
local type = type
local floor = math.floor
local unpack = unpack
local pairs = pairs
local ipairs = ipairs
local IsAddOnLoaded = IsAddOnLoaded
local hooksecurefunc = hooksecurefunc

local r, is = function(n, dec) return floor(n * (10 ^ (dec or 0)) + 0.5) end, function(v,t) return type(v) == t end
local dummy, d = function() end, lpanels.defaults

local class = (CUSTOM_CLASS_COLORS or RAID_CLASS_COLORS)[strupper(lpanels.cinfo.c)]
local function setcolor(color)
	if color == "CLASS" then
		return class.r, class.g, class.b
	elseif is(color,'string') then
		return strmatch(color, "([%d%.]+)%s+([%d%.]+)%s+([%d%.]+)")
	else return unpack(color) end
end

------------------------------------------------------------------------------------------
-- API: lpanels:CreateLayout("Layout Name", { _layout code_ }, { _viewport_ })
--	» arg1 - Layout name. Name can be anything at all.
--	» arg2 - Table with your layout code, can also be set as a variable.
--	» arg3 - Viewport table. ie: {top=10, bottom=100, left=5, right=5} or {bottom=100}
function lpanels:CreateLayout(name, layout, viewport)
	if name and (layout or viewport) then
		self.profile[name] = layout or {}
		if viewport then self.profile[name].Viewport = viewport end
	end
end

------------------------------------------------------------------------------------------
-- API: lpanels:ApplyLayout("n:Character r:Realm c:Class", "layout1", "layout2")
--  » arg1 - Profile string: May be set to any combination of n:ame, r:ealm, c:lass, 
--		separated by a single space. If nil, applies the specified layouts to all
--		characters. Additionally, a dash may be applied to front of the
--		condition (-n:ame -r:ealm -c:lass) to make the layout NOT load on the specified
--		value. The profile string is *not* CASE-sensitive.
--	» arg2,... - Layout names created by CreateLayout() to apply to this profile. No set
--      limit to how many layouts can be applied per profile.
function lpanels:MatchProf(profile,AND)
	local apply = false
	for a, str in gmatch(profile,'(%-?[nrc]):([^%s]+)') do
		if strmatch(self.cinfo[strlower(strsub(a,-1,-1))], strlower(str)) then
			if strmatch(a,'^%-') then return false else apply = true end
		elseif strmatch(a,'^%-') then apply = true elseif AND then return false end
	end
	return apply
end
function lpanels:ApplyLayout(profile, ...)
	if not profile or profile == "" then profile = "n:"..self.cinfo.n end
 	while strfind(profile,'%(.-%)') do
		for prof in gmatch(profile,'%(([^%(]-)%)') do
			profile = gsub(profile,'%('..gsub(prof,'%-','%%%-')..'%)', self:MatchProf(prof,1) and 'n:'..self.cinfo.n or 'n:x')
		end
	end
	if self:MatchProf(profile) then
		for _, name in ipairs{...} do
			if self.profile[name] then
				if self.profile[name].Viewport then self.profile.vp = self.profile[name].Viewport end
				for _, f in ipairs(self.profile[name]) do self.profile[#self.profile+1] = f end
			end
			self.profile[name] = nil
		end
	end
end

------------------------------------------------------------------------------------------
-- Core
function lpanels.RegisterEvent(self, event)
	if event == "PLAYER_LOGIN" then lpanels.temp.OnEvent(self,"PLAYER_LOGIN") end
end

local function Resize(panel, width, height)
	if width and height and (strmatch(width,"%d+%%") or strmatch(height,"%d+%%")) then
		-- resize based on the panel's anchor frame or parent if no anchor
		local _, parent = panel:GetPoint()
		local function hook(_, _width, _height)
			if strmatch(width,"%%") then panel:SetWidth(_width * strmatch(width,"(%d+)%%") * .01 + (strmatch(width,"%%%s([%+%-]%d+)") or 0)) end
			if strmatch(height,"%%") then panel:SetHeight(_height * strmatch(height,"(%d+)%%") * .01 + (strmatch(height,"%%.*([%+%-]%d+)") or 0)) end
		end
		parent:HookScript("OnSizeChanged", hook)
	end
end

function lpanels:MakePanel(f)
	-- setting a few defaults
	for _, attr in ipairs(self.defaultv) do if not f[attr] then f[attr] = d[attr] end end

	-- setting parent/anchor
	local origparent, origanchor
	for _, frame in pairs{f.parent, f.anchor_frame} do
		if is(frame,'string') and not _G[frame] then
			if not hidden[frame] then hidden[frame] = {} end tinsert(hidden[frame], f.name)
			f.parent, origparent, origanchor, f.anchor_frame = "lp_C", f.parent, f.anchor_frame
		end
	end
	f.parent = _G[f.parent] or _G[d.parent]

	-- create frame; object name will be LP_PanelName or LP_i if anonymous
	local panel = CreateFrame("Frame", f.name, f.parent)
	panel.bg = panel:CreateTexture(nil, "BACKGROUND")

	-- inserting some data into frame table
	if f.parent == lp_C then panel.parent, panel.anchor_frame, panel.strata, panel.level = origparent, origanchor, f.strata, f.level end
	panel.width, panel.height = f.width, f.height

	-- inset/outset; pos = inset, neg = outset
	if f.inset or f.border then
		if not f.inset then f.inset = f.border == "SOLID" and (f.border_size or 1) or (f.border_size or d.border_size) * 0.25 end
		local inset = {} for _,s in ipairs(self.sides) do
			inset[s] = is(f.inset,'table') and f.inset[s] or is(f.inset,'number') and f.inset or 0
		end
		panel.bg:SetPoint("TOPLEFT", inset.left, -inset.top)
		panel.bg:SetPoint("BOTTOMRIGHT", -inset.right, inset.bottom)
	else
		panel.bg:SetAllPoints(panel)
	end

	-- hide dependant frames, will show later for late loading addons
	if f.require and not IsAddOnLoaded(f.require) then deps[f.name] = f.require panel:Hide() end

	-- set positions
	panel:SetParent(f.parent)
	panel:ClearAllPoints()
	if strmatch(f.x_off, "%%") then f.x_off = (_G[f.anchor_frame] or f.parent):GetWidth() * strmatch(f.x_off,"(%d+)%%") * .01 end
	if strmatch(f.y_off, "%%") then f.y_off = (_G[f.anchor_frame] or f.parent):GetHeight() * strmatch(f.y_off,"(%d+)%%") * .01 end
	panel:SetPoint(strupper(f.anchor_to), _G[f.anchor_frame] or f.parent, strupper(f.anchor_from or f.anchor_to), f.x_off, f.y_off)
	if f.scale then panel:SetScale(f.scale) end

	-- height, width
	if f.parent ~= lp then Resize(panel, f.width, f.height) end
	panel:SetWidth(strmatch(f.width,"%%") and (_G[f.anchor_frame] or f.parent):GetWidth() * strmatch(f.width,"(%d+)%%") * .01 or f.width)
	panel:SetHeight(strmatch(f.height,"%%") and (_G[f.anchor_frame] or f.parent):GetHeight() * strmatch(f.height,"(%d+)%%") * .01 or f.height)

	-- strata, level
	panel:SetFrameStrata(f.strata or d.strata)
	if f.level then panel:SetFrameLevel(f.level) end

	-- default texts bg alpha, blend mode		
	if f.text and not f.bg_alpha and not f.tex_file and not f.bg_color then f.bg_alpha = 0 end
	if f.bg_blend then panel.bg:SetBlendMode(f.bg_blend) end

	-- texture art
	if f.tex_file then
		-- panel.bg:SetTexCoordModifiesRect(false) -- method removed in 3.3.3
		panel.bg:SetTexture(not strmatch(f.tex_file,"[/\\]") and self.media..f.tex_file or f.tex_file)
		if f.tex_coord then panel.bg:SetTexCoord(unpack(f.tex_coord)) end
		if f.tex_rotate then
			local coords = {}
			for i,c in ipairs{225,225,135,135,-45,-45,45,45} do
				coords[i] = 0.5+math[mod(i*0.5,2)==1 and "cos" or "sin"](rad(f.tex_rotate+c))*sqrt(0.5)
			end
			panel.bg:SetTexCoord(unpack(coords))
		end
		if f.flip_v or f.flip_h then
			local ULx,ULy,LLx,LLy,URx,URy,LRx,LRy = panel.bg:GetTexCoord()
			if f.flip_v then panel.bg:SetTexCoord(LLx,LLy,ULx,ULy,LRx,LRy,URx,URy) end
			if f.flip_h then panel.bg:SetTexCoord(URx,URy,LRx,LRy,ULx,ULy,LLx,LLy) end
		end
		if f.bg_color then panel.bg:SetVertexColor(setcolor(f.bg_color)) end
		if f.bg_alpha then panel.bg:SetAlpha(f.bg_alpha) end

	-- gradient texture
	elseif f.gradient and strmatch(f.gradient, "^[HV]") then
		local bg_r, bg_g, bg_b = setcolor(f.bg_color or d.bg_color)
		local gr_r, gr_g, gr_b = setcolor(f.gradient_color or d.gradient_color)
		local gradient = gsub(gsub(f.gradient,"^H.*","HORIZONTAL"),"^V.*","VERTICAL")
		panel.bg:SetGradientAlpha(gradient,bg_r,bg_g,bg_b,f.bg_alpha or d.bg_alpha,gr_r,gr_g,gr_b,f.gradient_alpha or f.bg_alpha or d.bg_alpha)
		panel.bg:SetTexture(1,1,1,1)

	-- solid texture
	else
		local bg_r, bg_g, bg_b = setcolor(f.bg_color or d.bg_color)
		panel.bg:SetTexture(bg_r,bg_g,bg_b,f.bg_alpha or d.bg_alpha)
	end

	-- borders
	if f.border then
		panel:SetBackdrop({
			edgeFile = f.border == true and d.border or f.border == "SOLID" and "Interface/Buttons/WHITE8X8" or not strmatch(f.border,"[/\\]") and self.media..f.border or f.border,
			edgeSize = (f.border == "SOLID" and not f.border_size) and 1 or f.border_size or d.border_size })
		local bo_r, bo_g, bo_b = setcolor(f.border_color or d.border_color)
		panel:SetBackdropBorderColor(bo_r,bo_g,bo_b,f.border_alpha or d.border_alpha)
	end

	-- texts
	if f.text then
		-- if f.text contains multiple tables, treat those tables as multiple text objects; name them self.text1,text2,text3,...
		f.text = is(f.text[1],'table') and f.text or {f.text}
		for i,t in ipairs(f.text) do
			if #f.text == 1 then i = "" end
			if is(t,'string') then t = {string=t} end
			panel["text"..i] = panel:CreateFontString(nil, "OVERLAY")
			local text = panel["text"..i]

			-- keep text string and frame height/width the same if nil
			if i == "" and (not f.width or not f.height or f.width == 0 or f.height == 0) then
				local function settext()
					panel:SetWidth(text:GetStringWidth())
					panel:SetHeight(text:GetStringHeight())
				end
				hooksecurefunc(text, "SetText", settext)
			end

			-- texts font
			if t.font and not strmatch(t.font,"[/\\]") then t.font = self.media..t.font end
			local flags = t.outline == 1 and "OUTLINE" or t.outline == 2 and "THICKOUTLINE"
			if t.mono then flags = (flags and flags..", " or "").."MONOCHROME" end
			text:SetFont(t.font or d.text.font, t.size or d.text.size, flags)
			if not text:GetFont() then -- handle invalid font error
				text:SetFont(d.text.font, t.size or d.text.size, flags)
				print("|cffffffffLite|cff66C6FFPanels  |cffff5555Font invalid:", strmatch(t.font, "([^/\\]+)$"))
			end
			
			-- texts string
			if not t.string then t.string = d.text.string end
			text:SetText(is(t.string,'function') and t.string(text) or t.string)

			-- texts color
			local tx_r, tx_g, tx_b = setcolor(t.color or d.text.color)
			text:SetTextColor(tx_r,tx_g,tx_b,t.alpha or d.text.alpha)

			-- texts shadow
			if (not t.shadow and not t.outline) or (t.shadow and t.shadow ~= 0) then 
				if not t.shadow then t.shadow = d.text.shadow end
				if is(t.shadow,'number') then t.shadow = {x=t.shadow,y=-t.shadow,alpha=d.text.shadow.alpha} end
				if is(t.shadow,'table') then			
					local sh_r, sh_g, sh_b = setcolor(t.shadow.color or d.text.shadow.color)
					text:SetShadowOffset(t.shadow.x or d.text.shadow.x, t.shadow.y or d.text.shadow.y)
					text:SetShadowColor(sh_r,sh_g,sh_b,t.shadow.alpha or d.text.shadow.alpha)
				end
			end

			-- texts positioning within panel
			text:SetJustifyH(t.justify_h or d.text.justify_h)
			text:SetJustifyV(t.justify_v or d.text.justify_v)
			text:SetPoint(strupper(t.anchor_to or d.text.anchor_to), panel, strupper(t.anchor_to or t.anchor_from or d.text.anchor_from), t.x_off or d.text.x_off, t.y_off or d.text.y_off)

			-- if it exists, hook text function to the frame's OnUpdate script
			if is(t.string,'function') and t.update ~= 0 then
				text.elapsed = 0
				local update, string = t.update or 1, t.string
				local function OnUpdate(self, u)
					text.elapsed = text.elapsed + u
					if text.elapsed > update then text:SetText(string(text)) text.elapsed = 0 end
				end
				if not f.OnUpdate then f.OnUpdate = OnUpdate else hooksecurefunc(f, "OnUpdate", OnUpdate) end
			end
		end
	end

	-- OnLoad handler
	if f.OnLoad then
		if f.OnEvent then -- fake PLAYER_LOGIN; it should have already fired
			hooksecurefunc(panel, "RegisterEvent", self.RegisterEvent)
			self.temp.OnEvent = f.OnEvent
		end
		f.OnLoad(panel)
	end

	-- scripting functions, args passed to layout's function
	if f.mouse ~= false and (f.mouse or f.OnClick or f.OnMouseDown or f.OnMouseUp or f.OnDoubleClick or f.OnEnter or f.OnLeave) then panel:EnableMouse(true) end
	for _, action in ipairs(lpanels.events) do
		local func = f[action]
		if is(func,'function') then
			if action == "OnDoubleClick" then
				panel.timer, panel.button = 0, nil
				local function hook(self, button)
					if self.timer and self.timer < time() then self.startTimer = false end
					if self.timer == time() and self.button == button and self.startTimer then
						self.startTimer = false
						func(self, button)
					else
						self.startTimer, self.timer, self.button = true, time(), button
					end
				end
				panel:HookScript("OnMouseUp", hook)
			else
				if action == "OnUpdate" then panel.elapsed = 0 end
				panel:HookScript(gsub(gsub(action,'OnClick','OnMouseUp'),'Resize','SizeChanged'), func)
			end
		end
	end
end

function lpanels:Init()
	if #self.profile == 0 then return end
		
	-- check if parent/anchor names are the names of other panels, then tag with 'LP_'
	for i, f in ipairs(self.profile) do for _, p in ipairs(self.profile) do
		if f.name ~= nil then
			if f.name == p.parent then p.parent = "LP_"..p.parent end
			if f.name == p.anchor_frame then p.anchor_frame = "LP_"..p.anchor_frame end
		end
	end f.name = f.name and "LP_"..f.name or "LP_"..i end
	
	-- set viewport
	if is(self.profile.vp,'table') then
		WorldFrame:ClearAllPoints()
		local vp = {} for _, s in ipairs(self.sides) do
			vp[s] = self.profile.vp[s] and self.profile.vp[s] * UIParent:GetScale() or 0
		end
		WorldFrame:SetPoint("TOPLEFT", vp.left, -vp.top)
		WorldFrame:SetPoint("BOTTOMRIGHT", -vp.right, vp.bottom)
	end

	-- begin to cycle through user profile and create panels
	for i,f in ipairs(self.profile) do self:MakePanel(f) end
end

function lpanels:Exit()
	r,is,class,setcolor,dummy = nil
	for k in pairs(self) do self[k] = nil end
	self.reset = 1 self.reset = nil
end

function lpanels.OnEvent(self, event)
	if event == "PLAYER_LOGIN" then
		-- pre-1.5 layout compatibility
		if LPanels then for name, profile in pairs(LPanels) do
			if name == "Default" or name == format("%s - %s", UnitName'player', GetRealmName()) then
				lpanels:CreateLayout(name, profile)
				lpanels:ApplyLayout(name ~= "Default" and "n:"..lpanels.cinfo.n.." r:"..lpanels.cinfo.r, name)
			end LPanels = nil
		end end
		-- run addon
		lpanels:Init()
		lpanels = lpanels:Exit()	
	elseif event == "ADDON_LOADED" and deps then
		for frame, addon in pairs(deps) do
			if IsAddOnLoaded(addon) then _G[frame]:Show() frame = nil end
		end 
	end
end

function lpanels.CreateFrame(_, frame)
	if not hidden[frame] then return end	
	for i, child in ipairs(hidden[frame]) do
		local panel = _G[child]
		if not panel.anchor_frame or _G[panel.anchor_frame] then
			local points = {panel:GetPoint()} points[2] = _G[panel.anchor_frame] or frame
			panel:SetParent(frame or UIParent)
			panel:ClearAllPoints() panel:SetPoint(unpack(points))
			Resize(panel, panel.width, panel.height)
			panel:SetFrameStrata(panel.strata)
			if panel.level then panel:SetFrameLevel(panel.level) end
			hidden[frame][i] = nil
		end
	end	
	if #hidden[frame] == 0 then hidden[frame] = nil end
end

hooksecurefunc("CreateFrame", lpanels.CreateFrame)

lp:RegisterEvent'ADDON_LOADED'
lp:RegisterEvent'PLAYER_LOGIN'
lp:SetScript("OnEvent", lpanels.OnEvent)

--[[
	LitePanels

	There is no gui config, this file will contain your panel configuration.
	Copy this file and save as layout.lua for it to begin working. Please use UTF-8 encoding.

	Syntax and examples for profiles is given at the bottom of this document. Most default
	values can be viewed at the top of core.lua.
	
	Generally, you'll want to use quotes around values that are not a number,
	true/false, or a {table} value. Other values, such as a parent frame name, strata, anchor,
	gradient orientation, or color "r g b" strings will require quotes around it.

	If you don't understand an attribute below, refer to the wowwiki link.
	
	=== Frame Attributes ===
	attribute [default value] http://reference-link
		Description.
				
	name [number in order created]
		Specifiy a name for your panel, this is useful for scripting or if you want to use
		it as a parent frame. Anonymous panels will be given a number by the order they're 
		listed in the profile. If you need to reference to a panel's name, the name will be 
		prefixed with 'LP_'. Ex: LP_GreenFrame or LP_1
	
	parent ["UIParent"]
		The frame you want to anchor this panel to. Panels will
		inheirit the scale and visibility (not alpha) of the parent.
	
	anchor_frame [parent]
		Sets the panel anchor frame if you'd like to anchor a panel to a frame other than 
		parent while keeping parent's visibility, scale, alpha, etc. Defaults to parent.
		
	anchor_to ["BOTTOMLEFT"] http://www.wowwiki.com/Widget_Anchor_Points
		Which side of the parent to anchor to.
	
	anchor_from [anchor_to *or* "BOTTOMLEFT"] http://www.wowwiki.com/Widget_Anchor_Points
		Which side of the panel to justify the anchor.

	require
		Require an addon to be loaded before showing this panel. Ex: {require="Dominos"},
		This does work with LoadOnDemand addons.

	x_off [0] http://www.wowwiki.com/API_Region_SetPoint
		Number of pixels along the x-axis. Negative moves panel left, positive moves it right.

	y_off [0] http://www.wowwiki.com/API_Region_SetPoint
		Number of pixels along the y-axis. Negative moves panel down, positive moves it up.

	strata ["BACKGROUND"] http://www.wowwiki.com/UITYPE_FrameStrata
		UI strata level you want to place your panel.

	level [1] http://www.wowwiki.com/FrameLevel
		This is a z-index level within the strata. If there's two panels with the same
		strata, a higher level will determine if a panel is shown overlapping the other.
		level can be set to 0 (zero) to place it behind its parent frame.

	width [0] http://www.wowwiki.com/API_Region_SetWidth
		Width of your panel in pixels or a percent. Ex: {width=110,} or {width="100%",}
		If anchor_frame is set, percents will use its width instead of the parent.
		
	height [0] http://www.wowwiki.com/API_Region_SetHeight
		Height of your panel in pixels or a percent. Ex: {height=50,} or {height="60%",}
		If anchor_frame is set, percents will use its height instead of the parent.
	
	bg_color ["0 0 0"] http://www.wowwiki.com/API_Texture_SetTexture
		Background color of the panel set as "r g b" or "CLASS" for class coloring.
		Number value must be between 0 and 1, numbers between must be expressed as a decimal.
		Ex: bg_color = "0 0.4 0.85",

		* The background object will be named `LP_name.bg` if you want to use it in a script.
		* If there is a background image, this value will be the image's vertex color.
		
	bg_alpha [1.0] http://www.wowwiki.com/API_UIObject_SetAlpha
		Opacity of the background color or texture represented as a decimal (0-1), 
		0 being completely transparent, and 1 being completely opaque.

	inset [0 or 1/4 of border_size]
		Number in pixels to indent the background. If negative, it will extend the background,
		creating a padding effect. Will try to automatically adjust itself when a border is set.
		Ex1: inset = -5 -- (same as inset={top=-5,bottom=-5,left=-5,right=-5})
		Ex2: inset = {top=5,bottom=5} -- (same as inset={top=5,bottom=5,left=0,right=0})	

	border [false] http://www.wowwiki.com/API_Frame_SetBackdrop
		This will set path to the border texture file. It can either be set to true to use
		the default ("Interface/Tooltips/UI-Tooltip-Border") or to the file of a different one.
		Ex1: border = true -- Uses default border texture.
		Ex2: border = "texture" -- If texture.tga is in the 'LitePanels/media/' folder.
		Ex3: border = "Interface\\AddOns\\SharedMedia\\border\\roth" -- For files elsewhere.
		Ex4: border = "SOLID" -- Creates a solid border, pixel size determined by border_size
		
	border_size [16] http://www.wowwiki.com/API_Frame_SetBackdrop
		Pixel size of edgeFile, i.e. border thickness and corner size.
		
	border_color ["1 1 1"] http://www.wowwiki.com/API_SetBackdropBorderColor
		Sets the color of the border as "red green blue", can be set to "CLASS" as well.
		Ex1: border_color = "0.5 0.1 1.0"
		Ex2: border_color = "CLASS"

	border_alpha [1.0] http://www.wowwiki.com/API_SetBackdropBorderColor
		Opacity of the border color. 1.0 = completely visible, 0.0 = completely transparent.
	
	gradient
		Gradient orientation of your background. May be represented as "H" (horizontal) or "V" (vertical).
		Ex1: gradient = "H"
		Ex2: gradient = "HORIZONTAL" -- Both work the same.
	
	gradient_color ["1 1 1"]
		Gradient color. First color will be bg_color, this will be the second color.
		See: bg_color

	gradient_alpha [1.0 or bg_alpha] http://www.wowwiki.com/API_UIObject_SetAlpha
		Opacity of the gradient background color. This value is separate from bg_alpha.
		See: bg_alpha
	
	bg_blend http://www.wowwiki.com/AlphaMode
		Alpha blending mode, see wowwiki doc.
	
	tex_file ["Interface\\AddOns\\LitePanels\\media\\**tex_file**"]
		Filename of your texture if you choose to use one. Width and height of the
		image itself must be in powers of two (8,16,32,64,128,256,512)
		If you put the files into the media folder inside the addon's folder, you can
		set this to the filename only, otherwise you must give the whole path.

	tex_coord http://www.wowwiki.com/API_Texture_SetTexCoord
		Advanced, see wowwiki doc.
		Ex: {left,right,top,bottom} or {ULx,ULy,LLx,LLy,URx,URy,LRx,LRy}

	tex_rotate [0]
		Number in degrees you'd like to rotate the texture. (0-360)

	flip_h and flip_v [false]
		If flip_h or flip_v is set to true, the texture will be mirrored
		horizontally or vertically. Ex: {flip_v=true,},

	mouse [false]
		Intercept mouse clicks on this frame; no clicking through.
		This is automatically set to true when using OnClick, OnMouseDown, OnMouseUp,
		OnDoubleClick, OnEnter, or OnLeave scripts.
	
	=== Texts ===
	To create text objects inside of an existing panel, use the following syntax:
	
	{ name = "SomePanel",
	  text = {
	    { attribute = value, attribute2 = value }, -- text object
	    { attribute = value, attribute2 = value }, -- another text object
	  },
	}
	
	* As you can see, you can create as many text objects per panel as you require. If you 
	only need one text object in your panel, you don't need to contain the attributes in 
	an extra curly brace pair like shown above. For example, this syntax would be
	perfectly fine for a single text object: `text = { attribute = value }`
	
	* When you create a single text, the text object will be named `panel.text`. If multiple
	texts are created, they'll be named text1,text2,text3,... in the order they're created.
	
	* A quick text object can be created with default formatting by using `text = "string"` as
	a normal frame attribute.
	
	* If there's a single text object, the frame's default height and width will be set to the
	text object's height and width.
	
	=== Texts Attributes ===
	string [""]
		The main text that will be displayed. This can also be a function with a return value 
		and will, by default, update every 1 second if created as one. This behavior is created 
		as a convenience so you will not need to create an OnUpdate script with a throttle.
		Ex: string = "Buffs"
		Ex: string = function(self)
			  self.tick = self.tick and self.tick + 1 or 0
			  return self.tick
			end
		
	update [1]
		This will only be needed if string is a function. This value is in seconds, and can also be
		a decimal. Ex: update = 0.1 (1/10 second)
		
	font ["Fonts/FRIZQT__.TTF"] http://www.wowwiki.com/API_FontInstance_SetFont
		Path to the font you want to use. Fonts placed in LitePanel's media folder can be used 
		by supplying only its filename.
		Ex1: font = "font.ttf" -- if in the 'LitePanels\media\' folder
		Ex2: font = "Interface\\AddOns\\SharedMedia\\fonts\\ABF.ttf" -- if file is elsewhere
		
	size [12] http://www.wowwiki.com/API_FontInstance_SetFont
		Font size of your text.
	
	color [{1,1,1}] http://www.wowwiki.com/API_FontInstance_SetTextColor
		Set the color of your text.
	
	alpha [1.0] http://www.wowwiki.com/API_FontInstance_SetTextColor
		Transparency of the text from 0.0-1.0. 0.0 is completely transparent, 1.0 is solid.
	
	outline [0] http://www.wowwiki.com/API_FontInstance_SetFont
		Sets the outline flag for the text. 1 for a thin outline, 2 for a thick outline.
		Setting an outline will automatically set the default value for shadow to zero.
	
	shadow [1] 
		Set the distance of the shadow in pixels from the text. Ex: `shadow = 1`
		The default shadow slope is: x = -y
		If you require more control over the shadow appearance,
		use `shadow = { attribute = value }` with the below attributes.
		:	x [1] 
		:		x-offset of the shadow on your text.
		:	y [-1]
		:		y-offset of the shadow on your text.
		:	color ["0 0 0"]
		:		Sets the color of the text's shadow.
		:	alpha [1]
		:		Sets the alpha of the text's shadow.
	
	mono [false] http://www.wowwiki.com/API_FontInstance_SetFont
		Set to true to enable the monochrome flag for the text.
	
	anchor_to ["CENTER"] http://www.wowwiki.com/API_Region_SetPoint
		Which side of the panel to anchor to.
	
	anchor_from ["CENTER"] http://www.wowwiki.com/API_Region_SetPoint
		Which side of the panel to justify the anchor.
	
	x_off [0] http://www.wowwiki.com/API_Region_SetPoint
		Number of pixels along the y-axis. Negative moves panel down, positive moves it up.
	
	y_off [0] http://www.wowwiki.com/API_Region_SetPoint
		Number of pixels along the x-axis. Negative moves panel left, positive moves it right.
		
	justify_h ["CENTER"]
		Sets horizontal text justification ("LEFT","RIGHT", or "CENTER") 
	
	justify_v ["MIDDLE"]
		Sets vertical text justification ("TOP","BOTTOM", or "MIDDLE") 
	
	=== Class Coloring ===
	All color attributes can be class colored fairly easily. Instead of inserting
	a color the standard "r g b", you would use "CLASS".
	Ex: bg_color = "CLASS", gradient_color = "CLASS", border_color = "CLASS"
	
	For a complete list of class colors and their actual color values
	see http://www.wowwiki.com/Class_colors
	
	=== Advanced: Script Attributes ===
	Script attributes are created the same way as regular attributes, except they must
	be assigned a function to be used for that event. 
	
	Currently supported handlers:
		OnClick, OnDoubleClick, OnMouseUp, OnMouseDown, OnEnter, OnLeave, OnUpdate,
		OnResize, OnLoad, OnEvent, OnHide, OnShow
	
	* Refer to wowwiki for details on these handlers. http://www.wowwiki.com/Widget_handlers
	
	* When using an OnUpdate script, you may use the predefined variable `self.elapsed` in a throttle:
	OnUpdate = function(self, u)
	  self.elapsed = self.elapsed + u
	  if elapsed > 3.0 then
	    -- code to run every 3 seconds
	    self.elapsed = 0
	  end
	end
	
	* If you need to define variables for multiple handlers, it may be best to use self.var_name
	and define it in your OnLoad handler:
	OnLoad = function(self)
	  self.clicks = 0
	end,
	OnClick = function(self, button)
	  self.clicks = self.clicks + 1
	  print(self.clicks, button)
	end
	
	-------------------------------------------------------------
	 Edit this layout, save, and type "/reload" to see your changes.

	 Read the above documentation fully before seeking support.
	------------------------------------------------------------- 
]]

------------------------------------------------------------------------------------------
-- API: lpanels:CreateLayout("Layout Name", { _layout code_ }, { _viewport_ })
--	» arg1 - Layout name. Name can be anything at all.
--	» arg2 - Table or reference with your layout code.
--	» arg3 - Viewport table (optional). ie: {top=10, bottom=100, left=5, right=5} or {bottom=100}

lpanels:CreateLayout("ActionBarsBG", {
	-- Action Bars -- centerbar and rightbar
	
{	name = "CenterPanel",
	anchor_frame = "AnchorBar1",
	strata = "BACKGROUND", level = 1,
	anchor_to = "TOPLEFT", x_off = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*2, y_off = 5,
	width = tDB["cfgBars"]["buSize"]*8+tDB["cfgBars"]["buOffset"]*7,
	height = AnchorBar1:GetHeight()+10,
    bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "CenterPanelTop",
	anchor_frame = "CenterPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "CenterPanelBottom",
	anchor_frame = "CenterPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "CenterPanelLeft",
	anchor_frame = "CenterPanel",
	strata = "BACKGROUND", level = 1,
	anchor_to = "LEFT", x_off = -tDB["cfgBars"]["buSize"]*2-tDB["cfgBars"]["buOffset"]*5, y_off = 0,
	width = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*5,
	height = "100%",
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "CenterPanelLeftTop",
	anchor_frame = "CenterPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

{	name = "CenterPanelLeftBottom",
	anchor_frame = "CenterPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

{	name = "CenterPanelRight",
	anchor_frame = "CenterPanel",
	strata = "BACKGROUND", level = 1,
	anchor_to = "RIGHT", x_off = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*5, y_off = 0,
	width = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*5,
	height = "100%",
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = 0,
},

{	name = "CenterPanelRightTop",
	anchor_frame = "CenterPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "CenterPanelRightBottom",
	anchor_frame = "CenterPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "RightPanel",
	parent = "MultiBarLeftButton3",
	anchor_frame = "AnchorBar2",
	strata = "BACKGROUND", level = 1,
	anchor_to = "TOPLEFT", x_off = -5, y_off = -tDB["cfgBars"]["buSize"]*2-tDB["cfgBars"]["buOffset"]*2,
	width = AnchorBar2:GetWidth()+10,
	height = tDB["cfgBars"]["buSize"]*8+tDB["cfgBars"]["buOffset"]*7,
    bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "RightPanelTop",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "LEFT", 
	width = 1, height = "100%",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightPanelBottom",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "RIGHT",
	width = 1, height = "100%",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightPanelLeft",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanel",
	strata = "BACKGROUND", level = 1,
	anchor_to = "TOP", x_off = 0, y_off = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*5,
	width = "100%",
	height = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*5,
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = 0,
},

{	name = "RightPanelLeftTop",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "LEFT", 
	width = 1, height = "100%",
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "RightPanelLeftBottom",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "RIGHT",
	width = 1, height = "100%",
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "RightPanelRight",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanel",
	strata = "BACKGROUND", level = 1,
	anchor_to = "BOTTOM", x_off = 0, y_off = -tDB["cfgBars"]["buSize"]*2-tDB["cfgBars"]["buOffset"]*5,
	width = "100%",
	height = tDB["cfgBars"]["buSize"]*2+tDB["cfgBars"]["buOffset"]*5,
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "RightPanelRightTop",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "LEFT", 
	width = 1, height = "100%",
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

{	name = "RightPanelRightBottom",
	parent = "MultiBarLeftButton3",
	anchor_frame = "RightPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "RIGHT",
	width = 1, height = "100%",
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

})

lpanels:CreateLayout("DatatextBG", {
	-- Left and right datatextBG

{	name = "InfoLeftPanel",
	anchor_frame = "AnchorLeftData",
	strata = "BACKGROUND", level = 1,
	anchor_to = "LEFT",
	width = "70%",
	height = "100%",
    bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "InfoLeftPanelTop",
	anchor_frame = "InfoLeftPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "InfoLeftPanelBottom",
	anchor_frame = "InfoLeftPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "InfoLeftPanelLeft",
	anchor_frame = "InfoLeftPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "LEFT", 
	width = 1, height = "100%",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "InfoLeftPanelRight",
	anchor_frame = "AnchorLeftData",
	strata = "BACKGROUND", level = 1,
	anchor_to = "RIGHT",
	width = "30%",
	height = "100%",
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = 0,
},

{	name = "InfoLeftPanelRightTop",
	anchor_frame = "InfoLeftPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "InfoLeftPanelRightBottom",
	anchor_frame = "InfoLeftPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "RightInfoPanel",
	anchor_frame = "AnchorRightData",
	strata = "BACKGROUND", level = 1,
	anchor_to = "RIGHT",
	width = "70%",
	height = "100%",
    bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "RightInfoPanelTop",
	anchor_frame = "RightInfoPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightInfoPanelBottom",
	anchor_frame = "RightInfoPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightInfoPanelLeft",
	anchor_frame = "RightInfoPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "RIGHT", 
	width = 1, height = "100%",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightInfoPanelRight",
	anchor_frame = "AnchorRightData",
	strata = "BACKGROUND", level = 1,
	anchor_to = "LEFT",
	width = "30%",
	height = "100%",
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "RightInfoPanelRightTop",
	anchor_frame = "RightInfoPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

{	name = "RightInfoPanelRightBottom",
	anchor_frame = "RightInfoPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

})

lpanels:CreateLayout("ChatLeft", {
	-- Chat bg
	
{	name = "LeftChatPanel",
	anchor_frame = "AnchorLeftChat",
	strata = "BACKGROUND", level = 1,
	anchor_to = "RIGHT",
	width = "70%",
	height = "100%",
    bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "LeftChatPanelTop",
	anchor_frame = "LeftChatPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "LeftChatPanelBottom",
	anchor_frame = "LeftChatPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "LeftChatPanelRight",
	anchor_frame = "LeftChatPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "RIGHT", 
	width = 1, height = "100%",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "LeftChatPanelLeft",
	anchor_frame = "AnchorLeftChat",
	strata = "BACKGROUND", level = 1,
	anchor_to = "LEFT",
	width = "30%",
	height = "100%",
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "LeftChatPanelRightTop",
	anchor_frame = "LeftChatPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], tDB["cfgMedia"]["pAlpha"],
},

{	name = "LeftChatPanelRightBottom",
	anchor_frame = "LeftChatPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

{	name = "LeftChatPanelLeftLeft",
	anchor_frame = "LeftChatPanelLeft",
	strata = "BACKGROUND", level = 5,
	anchor_to = "LEFT", 
	width = 1, height = "100%",
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

})

lpanels:CreateLayout("RightBG", {
	-- Right bg -- minimap,skada,smallAB

{	name = "RightChatPanel",
	anchor_frame = "RightBG",
	strata = "BACKGROUND", level = 1,
	anchor_to = "LEFT",
	width = "70%",
	height = "100%",
    bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
},

{	name = "RightChatPanelTop",
	anchor_frame = "RightChatPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightChatPanelBottom",
	anchor_frame = "RightChatPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightChatPanelLeft",
	anchor_frame = "RightChatPanel",
	strata = "BACKGROUND", level = 5,
	anchor_to = "LEFT", 
	width = 1, height = "100%",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
},

{	name = "RightChatPanelRight",
	anchor_frame = "RightBG",
	strata = "BACKGROUND", level = 1,
	anchor_to = "RIGHT",
	width = "30%",
	height = "100%",
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBG"], bg_alpha = tDB["cfgMedia"]["pAlpha"],
	gradient_color = tDB["cfgMedia"]["colorBG"], gradient_alpha = 0,
},

{	name = "RightChatPanelRightTop",
	anchor_frame = "RightChatPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "TOP", 
	width = "100%", height = 1,
	bg_color = tDB["cfgMedia"]["colorBR"], tDB["cfgMedia"]["pAlpha"],
},

{	name = "RightChatPanelRightBottom",
	anchor_frame = "RightChatPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "BOTTOM",
	width = "100%", height = 1,
	gradient = "H",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 1,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 0,
},

{	name = "RightChatPanelRightRight",
	anchor_frame = "RightChatPanelRight",
	strata = "BACKGROUND", level = 5,
	anchor_to = "RIGHT", 
	width = 1, height = "100%",
	gradient = "V",
	bg_color = tDB["cfgMedia"]["colorBR"], bg_alpha = 0,
	gradient_color = tDB["cfgMedia"]["colorBR"], gradient_alpha = 1,
},

})


if tDB.modules["cfgBars"] then lpanels:ApplyLayout(nil, "ActionBarsBG") end
if tDB.modules["cfgData"] then lpanels:ApplyLayout(nil, "DatatextBG") end
if tDB.modules["cfgChat"] then lpanels:ApplyLayout(nil, "ChatLeft") end
if tDB["cfgPanels"]["rBackground"] then lpanels:ApplyLayout(nil, "RightBG") end

end
tinsert(ThunderUI.modules, module)