﻿local _, addon = ...

local FormatTime = function(s)
    local day, hour, minute = 86400, 3600, 60
    if s >= day then
        return format("%dd", floor(s/day + 0.5)), s % day
    elseif s >= hour then
        return format("%dh", floor(s/hour + 0.5)), s % hour
    elseif s >= minute then
        return format("%dm", floor(s/minute + 0.5)), s % minute
    end
    return floor(s + 0.5), (s * 100 - floor(s * 100))/100
end

local backdrop = {
	bgFile = tDB["cfgMedia"]["textureBlank"],
	edgeFile = tDB["cfgMedia"]["textureBlank"], 
	tile = false, tileSize = 0, edgeSize = 1, 
	insets = {top = -1, left = -1, bottom = -1, right = -1},
}

local CreateAuraTimer = function(self,elapsed)
    if self.timeLeft then
        self.elapsed = (self.elapsed or 0) + elapsed
        if self.elapsed >= 0.1 then
            if not self.first then
                self.timeLeft = self.timeLeft - self.elapsed
            else
                self.timeLeft = self.timeLeft - GetTime()
                self.first = false
            end
            if self.timeLeft > 0 then
                local atime = FormatTime(self.timeLeft)
                self.remaining:SetText(atime)
            else
                self.remaining:Hide()
                self:SetScript("OnUpdate", nil)
            end
            self.elapsed = 0
        end
    end
end

local createAuraIcon = function(auras)
    local button = CreateFrame("Button", nil, auras)
    button:EnableMouse(false)

    button:SetSize(auras.size, auras.size)

    local icon = button:CreateTexture(nil, "OVERLAY")
    icon:SetAllPoints(button)
    icon:SetTexCoord(.07, .93, .07, .93)

    local overlay = CreateFrame("Frame", nil, button)
    overlay:SetAllPoints(button)
    overlay:SetBackdrop(backdrop)
	overlay:SetBackdropColor(0,0,0,0)
	overlay:SetBackdropBorderColor(unpack(tDB["cfgMedia"]["colorBR"])) 
    overlay:SetFrameLevel(6)
    button.overlay = overlay

    local font, fontsize = GameFontNormalSmall:GetFont()
    local count = overlay:CreateFontString(nil, "OVERLAY")
    count:SetFont(font, fontsize-1, "THINOUTLINE")
    count:SetPoint("LEFT", button, "BOTTOM", 3, 2)

    button:SetPoint("BOTTOMLEFT", auras, "BOTTOMLEFT")

    local remaining = button:CreateFontString(nil, "OVERLAY")
    remaining:SetPoint("CENTER") 
    remaining:SetFont(font, fontsize-1, "THINOUTLINE")
    remaining:SetTextColor(1, 1, 0)
    button.remaining = remaining

    button.parent = auras
    button.icon = icon
    button.count = count
    button.cd = cd
    button:Hide()

    auras.button = button
end

local updateDebuff = function(icon, texture, count, dtype, duration, timeLeft, buff)
    if(duration and duration > 0) then
        icon.remaining:Show()
    else
        icon.remaining:Hide()
    end

    local buffcolor =  { r = 0.0, g = 1.0, b = 1.0 }
    local color = buff and buffcolor or DebuffTypeColor[dtype] or DebuffTypeColor.none

    icon.overlay:SetBackdropBorderColor(color.r, color.g, color.b)

    icon.icon:SetTexture(texture)
    icon.count:SetText((count > 1 and count))

    icon.duration = duration
    icon.timeLeft = timeLeft
    icon.first = true
    icon:SetScript("OnUpdate", CreateAuraTimer)
end

local updateIcon = function(unit, auras)
    local cur
    local hide = true
    local index = 1
    while true do
        local name, rank, texture, count, dtype, duration, timeLeft, caster, isStealable, shouldConsolidate, spellID = UnitAura(unit, index, 'HARMFUL')
        if not name then break end
        --print(name..", "..spellID)
        local icon = auras.button
        local show = auras.CustomFilter(auras, unit, icon, name, rank, texture, count, dtype, duration, timeLeft, caster, isStealable, shouldConsolidate, spellID)

        if(show) then
            if not cur then
                cur = icon.priority
                updateDebuff(icon, texture, count, dtype, duration, timeLeft)
            else
                if icon.priority > cur then
                    updateDebuff(icon, texture, count, dtype, duration, timeLeft)
                end
            end

            icon:Show()
            hide = false
        end

        index = index + 1
    end

    index = 1
    while true do
        local name, rank, texture, count, dtype, duration, timeLeft, caster, isStealable, shouldConsolidate, spellID = UnitAura(unit, index, 'HELPFUL')
        if not name then break end
        --print(name..", "..spellID)
        local icon = auras.button
        local show = auras.CustomFilter(auras, unit, icon, name, rank, texture, count, dtype, duration, timeLeft, caster, isStealable, shouldConsolidate, spellID)

        if(show) and icon.buff then
            if not cur then
                cur = icon.priority
                updateDebuff(icon, texture, count, dtype, duration, timeLeft, true)
            else
                if icon.priority > cur then
                    updateDebuff(icon, texture, count, dtype, duration, timeLeft, true)
                end
            end

            icon:Show()
            hide = false
        end

        index = index + 1
    end

    if hide then
        auras.button:Hide()
    end
end

local Update = function(self, event, unit)
    if(self.unit ~= unit) then return end

    if(self.freebAuras) then
        updateIcon(unit, self.freebAuras)	
    end
end

local Enable = function(self)
    if(self.freebAuras) then
        createAuraIcon(self.freebAuras)
        self:RegisterEvent("UNIT_AURA", Update)

        return true
    end
end

local Disable = function(self)
    if(self.freebAuras) then
        self:UnregisterEvent("UNIT_AURA", Update)
    end
end

oUF:AddElement('freebDebuffs', Update, Enable, Disable)

local spellcache = setmetatable({}, {__index=function(t,v) local a = {GetSpellInfo(v)} if GetSpellInfo(v) then t[v] = a end return a end})
local function GetSpellInfo(a)
    return unpack(spellcache[a])
end

addon.auras = {
    debuffs = {
        -- Any Zone
	--	["Воздержанность"] = 1, -- воздержанность для тестов

		--Argaloth
		[GetSpellInfo(88942)] = 3, --Meteor Slash
		[GetSpellInfo(95172)] = 3, --Meteor Slash
		[GetSpellInfo(88954)] = 5, --Consuming Darkness
		[GetSpellInfo(95173)] = 5, --Consuming Darkness		
		
		--Magmaw
		[GetSpellInfo(89773)] = 5, --Mangle
		[GetSpellInfo(78941)] = 5, --Parasitic Infection

		--Omnitron Defense System
		[GetSpellInfo(79888)] = 5, --Lightning Conductor
		[GetSpellInfo(80161)] = 5, --Chemical Cloud
		[GetSpellInfo(80011)] = 5, --Soaked in Poison
		[GetSpellInfo(79505)] = 5, --Flamethrower
		[GetSpellInfo(80094)] = 5, --Fixate
		[GetSpellInfo(79501)] = 5, --Acquiring Target
		[GetSpellInfo(92053)] = 7,
		[GetSpellInfo(92023)] = 7,
	--	[GetSpellInfo(79501)] = 5, --Acquiring Target

		--Chimaeron
		[GetSpellInfo(89084)] = 8, --Low Health
		[GetSpellInfo(82890)] = 5, --Mortality
		[GetSpellInfo(82935)] = 6, --Caustic Slime
		[GetSpellInfo(82881)] = 7, --Break

		--Atramedes
		[GetSpellInfo(78092)] = 5, --Tracking
		[GetSpellInfo(77982)] = 6, --Searing Flame
		[GetSpellInfo(78023)] = 6, --Roaring Flame
		[GetSpellInfo(92988)] = 6, --

		--Maloriak
		[GetSpellInfo(78034)] = 5, --Rend 10-normal
		[GetSpellInfo(78225)] = 6, --Acid Nova 10-normal
		[GetSpellInfo(77615)] = 5, --Debilitating Slime 10-normal/25-normal
		[GetSpellInfo(77786)] = 6, --Consuming Flames 10-normal
		[GetSpellInfo(78617)] = 6, --Fixate
		[GetSpellInfo(77760)] = 6, --Biting Chill
		[GetSpellInfo(77699)] = 6, --Flash Freeze 10-normal

		--Nefarian
		[GetSpellInfo(81118)] = 5, --Magma 10-normal
		[GetSpellInfo(77827)] = 6, --Tail Lash 10-normal	
		[GetSpellInfo(79339)] = 10, --Magma 10-normal
		[GetSpellInfo(79318)] = 3, --Tail Lash 10-normal	
		
		-- Trash
		--Magma (falling off)
		[GetSpellInfo(81114)] = 5, --Magma
		[GetSpellInfo(81118)] = 5, --Magma
		--Tremors
		[GetSpellInfo(87931)] = 5, --Tremors
		--Phased Burn
		[GetSpellInfo(85799)] = 5, --Phased Burn
		--Crimson Flames
		[GetSpellInfo(88232)] = 5, --Crimson Flames
		--Twilight Soulblade
		[GetSpellInfo(84850)] = 5, --Soul Blade
		[GetSpellInfo(84853)] = 5, --Dark Pool
		--Crimsonborne Firestarter
		[GetSpellInfo(88219)] = 5, --Burning Twilight
		--Twilight Elementalist
		[GetSpellInfo(88079)] = 5, --Frostfire Bolt		
		
		--Halfus Wyrmbreaker
		[GetSpellInfo(83710)] = 5, --Furious Roar
		[GetSpellInfo(83908)] = 5, --Malevolent Strikes
		[GetSpellInfo(86157)] = 5, --Malevolent Strikes
		[GetSpellInfo(86158)] = 5, --Malevolent Strikes
		[GetSpellInfo(86159)] = 5, --Malevolent Strikes
		[GetSpellInfo(83603)] = 5, --Stone Touch

		-- Valiona and Theralion
		[GetSpellInfo(86788)] = 5, --Blackout 10-normal
		[GetSpellInfo(92876)] = 5, --Blackout 25-normal
		[GetSpellInfo(92877)] = 5, --Blackout
		[GetSpellInfo(92878)] = 5, --Blackout
		[GetSpellInfo(86622)] = 5, --Engulfing Magic 10-normal
		[GetSpellInfo(95639)] = 5, --Engulfing Magic 25-normal
		[GetSpellInfo(95640)] = 5, --Engulfing Magic
		[GetSpellInfo(95641)] = 5, --Engulfing Magic
		[GetSpellInfo(86202)] = 5, --Twilight Shift 10-normal
		[GetSpellInfo(92889)] = 5, --Twilight Shift 25-normal
		[GetSpellInfo(92890)] = 5, --Twilight Shift
		[GetSpellInfo(92891)] = 5, --Twilight Shift

		-- Twilight Ascendant Council
		[GetSpellInfo(82762)] = 5, --Waterlogged
		[GetSpellInfo(83099)] = 5, --Lightning Rod
		[GetSpellInfo(82285)] = 6, --Elemental Stasis
		[GetSpellInfo(82660)] = 6, --Burning Blood
		[GetSpellInfo(82665)] = 6, --Heart of Ice

		-- Cho'gall
		[GetSpellInfo(86028)] = 6, -- Cho's Blast
		[GetSpellInfo(86029)] = 6, -- Gall's Blast
		[GetSpellInfo(93189)] = 7, -- Corrupted Blood
		[GetSpellInfo(93133)] = 7, -- Debilitating Beam
		[GetSpellInfo(81836)] = 8, -- Corruption: Accelerated
		[GetSpellInfo(81831)] = 8, -- Corruption: Sickness
		[GetSpellInfo(82125)] = 8, -- Corruption: Malformation
		[GetSpellInfo(82170)] = 8, -- Corruption: Absolute 
		
		--Sinestra
		[GetSpellInfo(92956)] = 9, -- Wrack
		
		--Conclave of Wind
		[GetSpellInfo(84645)] = 5, --Wind Chill
		[GetSpellInfo(86111)] = 6, --Ice Patch
		[GetSpellInfo(86082)] = 7, --Permafrost
		[GetSpellInfo(86481)] = 7, --Hurricane
		[GetSpellInfo(86282)] = 7, --Toxic Spores
		[GetSpellInfo(85573)] = 8, --Deafening Winds
		[GetSpellInfo(85576)] = 8, --Withering Winds

		--Al'Akir
		[GetSpellInfo(88301)] = 5, --Acid Rain
		[GetSpellInfo(87873)] = 6, --Static Shock
		[GetSpellInfo(88427)] = 6, --Electrocute
		[GetSpellInfo(89666)] = 6, --Lightning Rod
		[GetSpellInfo(89668)] = 6, --Lightning Rod
		
    },

    buffs = {
        --[GetSpellInfo(871)] = 15, -- Shield Wall
    },

    instances = {
        -- Raid Debuffs
        --["Zone"] = {
        --	[Name or GetSpellInfo(#)] = PRIORITY,
        --},
    },
}

local _, class = UnitClass("player")
local mediapath = "Interface\\AddOns\\TheThunderUI\\media\\"
local indicator = mediapath.."squares.ttf"
local symbols = mediapath.."PIZZADUDEBULLETS.ttf"

local Enable = function(self)
    if(self.freebIndicators) then
        self.AuraStatusTL = self.Health:CreateFontString(nil, "OVERLAY")
        self.AuraStatusTL:ClearAllPoints()
        self.AuraStatusTL:SetPoint("TOPLEFT", 0, -1)
        self.AuraStatusTL:SetFont(indicator, 6, "THINOUTLINE")
        self:Tag(self.AuraStatusTL, addon.classIndicators[class]["TL"])

        self.AuraStatusTR = self.Health:CreateFontString(nil, "OVERLAY")
        self.AuraStatusTR:ClearAllPoints()
        self.AuraStatusTR:SetPoint("TOPRIGHT", 2, -1)
        self.AuraStatusTR:SetFont(indicator, 6, "THINOUTLINE")
        self:Tag(self.AuraStatusTR, addon.classIndicators[class]["TR"])
		
        self.AuraStatusBL = self.Health:CreateFontString(nil, "OVERLAY")
        self.AuraStatusBL:ClearAllPoints()
        self.AuraStatusBL:SetPoint("BOTTOM")
        self.AuraStatusBL:SetJustifyH("CENTER")
        self.AuraStatusBL:SetFont(tDB["unitframes"]["font"], tDB["unitframes"]["fontsize"]+1)
        self.AuraStatusBL:SetShadowOffset(1.25, -1.25)
        self:Tag(self.AuraStatusBL, addon.classIndicators[class]["BL"])	

        self.AuraStatusBR = self.Health:CreateFontString(nil, "OVERLAY")
        self.AuraStatusBR:ClearAllPoints()
        self.AuraStatusBR:SetPoint("BOTTOMRIGHT", 6, -2)
        self.AuraStatusBR:SetFont(symbols, tDB["unitframes"]["gridIconSize"], "THINOUTLINE")
        self:Tag(self.AuraStatusBR, addon.classIndicators[class]["BR"])

        self.AuraStatusCen = self.Health:CreateFontString(nil, "OVERLAY")
        self.AuraStatusCen:ClearAllPoints()
        self.AuraStatusCen:SetPoint("TOP")
        self.AuraStatusCen:SetJustifyH("CENTER")
        self.AuraStatusCen:SetFont(tDB["unitframes"]["font"], tDB["unitframes"]["fontsize"]-1)
        self.AuraStatusCen:SetShadowOffset(1.25, -1.25)
        self:Tag(self.AuraStatusCen, addon.classIndicators[class]["Cen"])
    end
end

oUF:AddElement('freebIndicators', nil, Enable, nil)